==> adv-repulsion-systems_50.0.1_for_1.3.2-joined.jar: mod_shared/immibis/ars/ItemMFD_offset.java <==
package immibis.ars;

import immibis.ars.projectors.TileProjector;
import immibis.ars.projectors.TileProjectorExtender;
import immibis.core.api.Dir;
import immibis.core.api.porting.SidedProxy;

import java.util.List;

import net.minecraft.src.EntityPlayer;
import net.minecraft.src.ItemStack;
import net.minecraft.src.Slot;
import net.minecraft.src.TileEntity;
import net.minecraft.src.World;

public class ItemMFD_offset extends ItemMFD {

	public ItemMFD_offset(int i) {
		super(i, 2);
		setIconIndex(5);
	}
	
	private int clamp(int i) {
		if(i < -TileProjector.maxOffset)
			return -TileProjector.maxOffset;
		if(i > TileProjector.maxOffset)
			return TileProjector.maxOffset;
		return i;
	}

	public boolean onItemUse(ItemStack itemstack, EntityPlayer entityplayer, World world, int x, int y, int z, int side) {
		TileEntity te = world.getBlockTileEntity(x, y, z);
		if(te instanceof TileProjector && !(te instanceof TileProjectorExtender)) {
			TileProjector p = (TileProjector)te;
			if(p.getActive()) {
				SidedProxy.instance.sendChat("Cannot move an active forcefield.", entityplayer);
				return true;
			}
			int step = entityplayer.isSneaking() ? -1 : 1;
			switch(side) {
			case Dir.NX: p.offsetX = clamp(p.offsetX + step); break;
			case Dir.NY: p.offsetY = clamp(p.offsetY + step); break;
			case Dir.NZ: p.offsetZ = clamp(p.offsetZ + step); break;
			case Dir.PX: p.offsetX = clamp(p.offsetX - step); break;
			case Dir.PY: p.offsetY = clamp(p.offsetY - step); break;
			case Dir.PZ: p.offsetZ = clamp(p.offsetZ - step); break;
			}
			SidedProxy.instance.sendChat("New field offset: "+p.offsetX+","+p.offsetY+","+p.offsetZ, entityplayer);
			return true;
		}
		return false;
	}
}

==> adv-repulsion-systems_50.2.3_for_1.3.2-joined.jar: mod_shared/immibis/ars/ItemMFD_offset.java <==
package immibis.ars;

import immibis.ars.projectors.TileProjector;
import immibis.ars.projectors.TileProjectorExtender;
import immibis.core.api.Dir;
import immibis.core.api.porting.SidedProxy;

import net.minecraft.src.EntityPlayer;
import net.minecraft.src.ItemStack;
import net.minecraft.src.TileEntity;
import net.minecraft.src.World;

public class ItemMFD_offset extends ItemMFD {

	public ItemMFD_offset(int i) {
		super(i, 2);
		setIconIndex(5);
	}
	
	private int clamp(int i) {
		if(i < -TileProjector.maxOffset)
			return -TileProjector.maxOffset;
		if(i > TileProjector.maxOffset)
			return TileProjector.maxOffset;
		return i;
	}

	@Override
	/* $if mc >= 1.3$ */
	public boolean onItemUse(ItemStack itemstack, EntityPlayer entityplayer, World world, int x, int y, int z, int side, float x1, float x2, float x3) {
	/* $else$
	public boolean onItemUse(ItemStack itemstack, EntityPlayer entityplayer, World world, int x, int y, int z, int side) {
	$endif$ */
		
		TileEntity te = world.getBlockTileEntity(x, y, z);
		if(te instanceof TileProjector && !(te instanceof TileProjectorExtender)) {
			if(world.isRemote)
				return true;
			
			TileProjector p = (TileProjector)te;
			if(p.getActive()) {
				SidedProxy.instance.sendChat("Cannot move an active forcefield.", entityplayer);
				return true;
			}
			int step = entityplayer.isSneaking() ? -1 : 1;
			switch(side) {
			case Dir.NX: p.offsetX = clamp(p.offsetX + step); break;
			case Dir.NY: p.offsetY = clamp(p.offsetY + step); break;
			case Dir.NZ: p.offsetZ = clamp(p.offsetZ + step); break;
			case Dir.PX: p.offsetX = clamp(p.offsetX - step); break;
			case Dir.PY: p.offsetY = clamp(p.offsetY - step); break;
			case Dir.PZ: p.offsetZ = clamp(p.offsetZ - step); break;
			}
			SidedProxy.instance.sendChat("New field offset: "+p.offsetX+","+p.offsetY+","+p.offsetZ, entityplayer);
			return true;
		}
		return false;
	}
}
